/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { Component, useState, useEffect } from 'react';
import styled from 'styled-components';
import Tabs from '@material-ui/core/Tabs'
import Tab from '@material-ui/core/Tab';
import Breadcrumbs from '@material-ui/core/Breadcrumbs';
import Grid from '@material-ui/core/Grid';
import Why from '../../Components/HelpCenter/TabsResoursePub/Why'
import How from '../../Components/HelpCenter/TabsResoursePub/How'
import CardEncontrando from '../../Components/HelpCenter/Cards/CardEncontrando';
import CardParticipando from '../../Components/HelpCenter/Cards/CardParticipando';
import CardGerenciando from '../../Components/HelpCenter/Cards/CardGerenciando';
import What from '../../Components/HelpCenter/TabsPlataformaMEC/What';
import Understand from '../../Components/HelpCenter/TabsPlataformaMEC/Understand';
import Which from '../../Components/HelpCenter/TabsPlataformaMEC/Which';
import Types from '../../Components/HelpCenter/TabsPlataformaMEC/Types';
import Software from '../../Components/HelpCenter/TabsPlataformaMEC/Software';







export default function TabPlataformaMEC (props) {
  const tabs= [
    'O que é a plataforma MEC?',
    'Como foi construída a Plataforma MEC?',
    'Entendendo as 3 áreas da Plataforma',
    'Quais são os Portais Parceiros?',
    'Tipos de recursos',
    'Softwares específicos'
  ]
  
  const [tabValue, setTabValue] = useState(
    Number(props.location.state.value) || 0);

  const handleChangeTab = (e, newValue) => {
    setTabValue(newValue)
}



  return(
    <div style={{backgroundColor:"#f4f4f4"}}>
      <link href="https://fonts.googleapis.com/css?family=Pompiere|Roboto:500,400&display=swap" rel="stylesheet"/>
      
      <Secao>
        <Grid container spacing={4}>
          <Grid item xs={3}>
            <Menu>
              <h4>Plataforma MEC</h4>
              <TabsStyled orientation = "vertical"
                          variant = "scrollable"
                          value = {tabValue}
                          onChange = {handleChangeTab}
                          TabIndicatorProps = {{style:{display: "none"}}}
              >
              <TabStyled label={tabs[0]}></TabStyled>
              <TabStyled label={tabs[1]}></TabStyled>
              <TabStyled label={tabs[2]}></TabStyled>
              <TabStyled label={tabs[3]}></TabStyled>
              <TabStyled label={tabs[4]}></TabStyled>
              <TabStyled label={tabs[5]}></TabStyled>
              </TabsStyled>
              <br/>
              <div className="voltarInicio">
                <a href="ajuda">VOLTAR AO ÍNICIO</a>
              </div>
              <hr/>
              <div className="procurava">
                Não encontrou o que procurava? Entre em 
                <a href="contato"> contato</a>
              </div>
            </Menu>
          </Grid>

          <Grid item xs={9}>
            <Principal>
              {tabValue === 0 && <What title={tabs[0]}/>}
              {tabValue === 1 && <How title={tabs[1]}/>}
              {tabValue === 2 && <Understand title={tabs[2]}/>}
              {tabValue === 3 && <Which title={tabs[2]}/>}
              {tabValue === 4 && <Types title={tabs[2]}/>}
              {tabValue === 5 && <Software title={tabs[2]}/>}
              
              <Grid style={{marginBlock:"50px"}} container spacing={2}>
                <Grid item xs={4}>
                  <CardEncontrando/>
                </Grid>
                <Grid item xs={4}>
                  <CardParticipando/>
                </Grid>
                <Grid item xs={4}>
                  <CardGerenciando/>
                </Grid>

              </Grid>

            </Principal>
          </Grid>  
        </Grid>        


      </Secao>
    </div>
  );
}

const Principal = styled.div`
  .fixo {
    
    height: 40px;
    text-align: center;
    background-color: #fff;
    box-shadow: 0 1px 3px rgba(0,0,0,.12),0 1px 2px rgba(0,0,0,.24);
    padding: 30px;
    margin-bottom: 30px;
    color: #666;


    img {
      height: 50px;
      width: 50px;
      margin-right: 40px;
      vertical-align: middle;

    }

    span {
      font-size: 20px;
      vertical-align: ;
    }

    

  }
 
`

const TabsStyled = styled(Tabs)`
  
  .Mui-selected {
    background-color: #e7e4e4;
  }

  .MuiTab-root{
    text-transform: none !important;
  }

`

const TabStyled = styled(Tab)`
    
  padding: 4px 15px !important;
  font-weight: 500;
  font-size: 14px !important;
  border-radius: 4px !important;


  


  &:hover {
    background-color: #e7e4e4;
  }
`


const Menu = styled.div`
  width: auto;
  background-color: #fff;
  color: #666;
  padding-block: 10px;
  box-shadow: 0 1px 3px rgba(0,0,0,.12),0 1px 2px  rgba(0,0,0,.24);

  h4 {
    padding-inline: 15px;
    font-size: 18px;
    margin-block: 10px;
    font-weight: 500;
    line-height: 1.1;
  }

  .voltarInicio {
    padding: 4px 15px;
    font-size: 15px;
    text-align: center;
    a {
      font-size: 15px;
      padding: 0;
      color:#00bcd4;
      text-decoration: none;
    }
  }

  hr {
    border: 0;
    border-top: 1px solid #ccc;
    margin-top: 20px;
    margin-bottom: 20px;
  }

  .procurava {
    padding: 4px 15px;
    font-size: 15px;
    text-align: center;

    a {
      font-size: 15px;
      padding: 0;
      color:#00bcd4;
      text-decoration: none;
    }

  }

`

const Secao = styled.div`
  width: 1138px;
  margin-inline: auto;

`
